Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/infra/gmfdiag/org.eclipse.papyrus.infra.gmfdiag.css.model/src-gen/org/eclipse/papyrus/infra/gmfdiag/css/stylesheets/StylesheetsFactory.java')
-rw-r--r--plugins/infra/gmfdiag/org.eclipse.papyrus.infra.gmfdiag.css.model/src-gen/org/eclipse/papyrus/infra/gmfdiag/css/stylesheets/StylesheetsFactory.java138
1 files changed, 78 insertions, 60 deletions
diff --git a/plugins/infra/gmfdiag/org.eclipse.papyrus.infra.gmfdiag.css.model/src-gen/org/eclipse/papyrus/infra/gmfdiag/css/stylesheets/StylesheetsFactory.java b/plugins/infra/gmfdiag/org.eclipse.papyrus.infra.gmfdiag.css.model/src-gen/org/eclipse/papyrus/infra/gmfdiag/css/stylesheets/StylesheetsFactory.java
index 27b6b2da365..d11cbef6314 100644
--- a/plugins/infra/gmfdiag/org.eclipse.papyrus.infra.gmfdiag.css.model/src-gen/org/eclipse/papyrus/infra/gmfdiag/css/stylesheets/StylesheetsFactory.java
+++ b/plugins/infra/gmfdiag/org.eclipse.papyrus.infra.gmfdiag.css.model/src-gen/org/eclipse/papyrus/infra/gmfdiag/css/stylesheets/StylesheetsFactory.java
@@ -1,60 +1,78 @@
-/**
- */
-package org.eclipse.papyrus.infra.gmfdiag.css.stylesheets;
-
-import org.eclipse.emf.ecore.EFactory;
-
-/**
- * <!-- begin-user-doc -->
- * The <b>Factory</b> for the model.
- * It provides a create method for each non-abstract class of the model.
- * <!-- end-user-doc -->
- * @see org.eclipse.papyrus.infra.gmfdiag.css.stylesheets.StylesheetsPackage
- * @generated
- */
-public interface StylesheetsFactory extends EFactory {
- /**
- * The singleton instance of the factory.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @generated
- */
- StylesheetsFactory eINSTANCE = org.eclipse.papyrus.infra.gmfdiag.css.stylesheets.impl.StylesheetsFactoryImpl.init();
-
- /**
- * Returns a new object of class '<em>Model Style Sheets</em>'.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @return a new object of class '<em>Model Style Sheets</em>'.
- * @generated
- */
- ModelStyleSheets createModelStyleSheets();
-
- /**
- * Returns a new object of class '<em>Style Sheet Reference</em>'.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @return a new object of class '<em>Style Sheet Reference</em>'.
- * @generated
- */
- StyleSheetReference createStyleSheetReference();
-
- /**
- * Returns a new object of class '<em>Embedded Style Sheet</em>'.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @return a new object of class '<em>Embedded Style Sheet</em>'.
- * @generated
- */
- EmbeddedStyleSheet createEmbeddedStyleSheet();
-
- /**
- * Returns the package supported by this factory.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- * @return the package supported by this factory.
- * @generated
- */
- StylesheetsPackage getStylesheetsPackage();
-
-} //StylesheetsFactory
+/**
+ */
+package org.eclipse.papyrus.infra.gmfdiag.css.stylesheets;
+
+import org.eclipse.emf.ecore.EFactory;
+
+/**
+ * <!-- begin-user-doc -->
+ * The <b>Factory</b> for the model.
+ * It provides a create method for each non-abstract class of the model.
+ * <!-- end-user-doc -->
+ * @see org.eclipse.papyrus.infra.gmfdiag.css.stylesheets.StylesheetsPackage
+ * @generated
+ */
+public interface StylesheetsFactory extends EFactory {
+ /**
+ * The singleton instance of the factory.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @generated
+ */
+ StylesheetsFactory eINSTANCE = org.eclipse.papyrus.infra.gmfdiag.css.stylesheets.impl.StylesheetsFactoryImpl.init();
+
+ /**
+ * Returns a new object of class '<em>Model Style Sheets</em>'.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @return a new object of class '<em>Model Style Sheets</em>'.
+ * @generated
+ */
+ ModelStyleSheets createModelStyleSheets();
+
+ /**
+ * Returns a new object of class '<em>Style Sheet Reference</em>'.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @return a new object of class '<em>Style Sheet Reference</em>'.
+ * @generated
+ */
+ StyleSheetReference createStyleSheetReference();
+
+ /**
+ * Returns a new object of class '<em>Embedded Style Sheet</em>'.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @return a new object of class '<em>Embedded Style Sheet</em>'.
+ * @generated
+ */
+ EmbeddedStyleSheet createEmbeddedStyleSheet();
+
+ /**
+ * Returns a new object of class '<em>Workspace Themes</em>'.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @return a new object of class '<em>Workspace Themes</em>'.
+ * @generated
+ */
+ WorkspaceThemes createWorkspaceThemes();
+
+ /**
+ * Returns a new object of class '<em>Theme</em>'.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @return a new object of class '<em>Theme</em>'.
+ * @generated
+ */
+ Theme createTheme();
+
+ /**
+ * Returns the package supported by this factory.
+ * <!-- begin-user-doc -->
+ * <!-- end-user-doc -->
+ * @return the package supported by this factory.
+ * @generated
+ */
+ StylesheetsPackage getStylesheetsPackage();
+
+} //StylesheetsFactory

Back to the top